@@ -202,6 +202,13 @@ def sample_patch_tgz_no_series(tmp_path, sample_patch, sample_patch_dir):
     return str(tar_file)
 
 
+@pytest.fixture
+def sample_patch_mbx(tmp_path, sample_patch, sample_patch_dir):
+    p = tmp_path / "patch.mbx"
+    p.write_text(sample_patch)
+    return str(p)
+
+
 @pytest.fixture
 def sample_manifest():
     return '<?xml version="1.0" encoding="UTF-8"?><manifest></manifest>'
