@@ -962,6 +962,37 @@ class TestHandlePatch:
         assert result[0] == url
         assert base64.b64decode(result[1]) == b""
 
+    def test_handle_patch_mbx(self, mocker, sample_patch, sample_patch_mbx):
+        guess = mocker.patch(
+            "mimetypes.guess_type", return_value=("application/mbox", None)
+        )
+        result = tuxsuite.build.handle_patch(sample_patch_mbx)
+        assert guess.call_count == 1
+        assert isinstance(result, type(()))
+        assert isinstance(type(result[0]), type(str))
+        assert base64.b64decode(result[1]) == sample_patch.encode("utf-8")
+
+    def test_handle_patch_lore_url(self, mocker):
+        mocker.patch("shutil.which", return_value=True)
+        mocker.patch("subprocess.check_output")
+        mocker.patch("os.path.isfile", return_value=True)
+        mocker.patch("os.rename", return_value=True)
+        mocker.patch("builtins.open", mocker.mock_open(read_data=b"fakepatch"))
+        url = "https://lore.kernel.org/lkml/YmkO7LDc0q38VFlE@kroah.com/raw"
+        result = tuxsuite.build.handle_patch(url)
+        assert isinstance(result, type(()))
+        assert isinstance(type(result[0]), type(str))
+
+    def test_handle_patch_lore_url_no_b4(self, mocker, capsys):
+        mocker.patch("shutil.which", return_value=False)
+        url = (
+            "https://lore.kernel.org/lkml/20220426143216.GE18291@alpha.franken.de/T/#t"
+        )
+        with pytest.raises(SystemExit):
+            tuxsuite.build.handle_patch(url)
+        output, error = capsys.readouterr()
+        assert "'b4' not found" in output
+
 
 @pytest.fixture
 def test_attrs():
