@@ -774,6 +774,7 @@ class Test(HeadersMixin):
     scp_romfw = attrib(default=None)
     fip = attrib(default=None)
     tests = attrib(default=[])
+    timeouts = attrib(default=[])
     boot_args = attrib(default=None)
     wait_for = attrib(default=None)
     uid = attrib(default=None)
@@ -804,6 +805,8 @@ class Test(HeadersMixin):
             data["modules"] = self.modules
         if self.tests:
             data["tests"] = self.tests
+        if self.timeouts:
+            data["timeouts"] = self.timeouts
         if self.boot_args:
             data["boot_args"] = self.boot_args
         if self.wait_for:
